from .materialized_views.materialized_view_from_queryset import MaterializedViewFromQueryset
from .materialized_views.materialized_view_from_raw_sql import MaterializedViewFromRawSql
from .my_test_model import MyTestModel



# Generated by Django 4.1.7 on 2023-03-16 09:48

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('example_app', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='MaterializedViewFromQueryset',
            fields=[
                ('my_test_model', models.ForeignKey(on_delete=django.db.models.deletion.DO_NOTHING, primary_key=True, serialize=False, to='example_app.mytestmodel')),
                ('count', models.IntegerField()),
            ],
            options={
                'abstract': False,
                'managed': False,
            },
        ),
    ]
